# pinard

pinard is a python package developed at CIRAD (www.cirad.fr) by Grégory Beurier (beurier@cirad.fr), Denis Cornet (denis.cornet@cirad.fr) and Lauriane Rouan (lauriane.rouan@cirad.fr) to enhance Near Infrared Spectroscopy files processing.

It provides set of tools to load, filter, noise, manage and regress sets of NIRS spectrum files. 

## INSTALLATION
tensorflow 2.6.2
cuda 11.2
python 3.7.9


pinard is available with pip:

pip install pinard

## USAGE

see examples

## TODO AND EXTENSIONS
### critical
- Kennard Stone parallel implementation
- Reup tests
### low
- reimplement extended multiplicative scatter correction with its inverse transform


### sets
- save / load
- compressed representation to minimize memory print

### augmentation
- noises and data structures

### learning
- all